//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","B4:WSSTR Confirmation","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","C4:WSSTR ObjectBox","֥ȥܥå");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","D4:WSSTR ProjectSettings","ץ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","E4:WSSTR New project","ץȤο");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","F4:WSSTR Open project","ץȤɤ߹");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","G4:WSSTR Save project","ץȤ¸");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","H4:WSSTR Close project","ץȤνλ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","I4:WSSTR New application window","ɥο");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","J4:WSSTR Open application window","ɥɤ߹");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","K4:WSSTR Save application window","ɥ¸");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","L4:WSSTR Delete instance","ɥ/֥Ȥκ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","M4:WSSTR Properties","ץѥƥԽ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","N4:WSSTR Procedures","ץ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","O4:WSSTR Display the object box","֥ȥܥå");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","P4:WSSTR Project settings","ץȤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Q4:WSSTR Build all","ӥɥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Q4:WSSTR Cancel","ӥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","R4:WSSTR Execute","¹");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","S4:WSSTR Find instances","ɥ/󥹥󥹤θ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","T4:WSSTR Find files","ե븡");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","U4:WSSTR Help","إ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","V4:WSSTR  File(F)"," ե(F)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","W4:WSSTR New window(N)         :m11:N,Open window(O):m12:O,Save window(S):m13:S,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X","ɥ(N)      :m11:N:0:$(WSDIR)/sys/pixmaps/wcreate.png,ɥɤ߹(O):m12:O:0:$(WSDIR)/sys/pixmaps/wload.png,ɥ¸(S):m13:S:0:$(WSDIR)/sys/pixmaps/wsave.png,ɥ̾¸(R):m14:R:0:,ɥ¸(A):m15:A:0:,SP,ӥλ(X):m16:X:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","X4:WSSTR  Edit(E)"," Խ(E)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L","᤹(U):m291:U:1,ʣ(C):m21:C,Žդ(P):m22:P,SP,ɽ(I):m27:I,󥹥󥹤θ(F):m28:F,(D):m23:D,SP,ץѥƥԽ(R):m24:R,ץԽ:{ץ(L):m25:L,ץ㿷(N):m251:N,ץ(S):m252:S,ץԽ(E):m253:E,ץ(X):m254:X},(A):m26:A,ե(L):m29:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Z4:WSSTR  Build(B)"," ӥ(B)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","a4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","ѥ(C)    :m31:C,ӥɥ(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,ӥ(R):m33:R,꡼(E):m34:E,SP,ǥХå(D):m35:D,¹(X):m36:X:0:$(WSDIR)/sys/pixmaps/run.png,ȥ졼¹(T):m39:T,SP,(G):m37:G,ν(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","b4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","ѥ(C)    :m31:C,ӥɥ(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,ӥ(R):m33:R,꡼(E):m34:E,SP,ǥХå(D):m35:D,¹(X):m36:X:0:$(WSDIR)/sys/pixmaps/runx.png,SP,(G):m37:G,ν(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","c4:WSSTR  View(V)"," ɽ(V)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","d4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Terminal(T):m45:T","ե(D) :m46:D,󥹥ڥ(I) :m47:I,󥹥󥹥ǥ(E) :m48:E,饹ꥹ(L) :m49:L,֥ȥܥå(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,ݡͥ(C):m42:C,ġС(B):m43:B,SP,ߥʥ(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","e4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Find Files(F):m44:F,Terminal(T):m45:T","ե(D) :m46:D,󥹥ڥ(I) :m47:I,󥹥󥹥ǥ(E) :m48:E,饹ꥹ(L) :m49:L,֥ȥܥå(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,ݡͥ(C):m42:C,ġС(B):m43:B,SP,ե븡(F):m44:F,ߥʥ(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","f4:WSSTR  Project(P)"," ץ(P)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","g4:WSSTR New project(N)        :m51:N,Open project(O):m52:O,Save project(S):m53:S,Rename project(R):m54:R,SP,Project settings(E):m55:E,SP,Close project(C):m56:C","ץ(N)      :m51:N:0:$(WSDIR)/sys/pixmaps/pcreate.png,ץɤ߹(O) :m52:O:0:$(WSDIR)/sys/pixmaps/pload.png,ץ¸(S):m53:S:0:$(WSDIR)/sys/pixmaps/psave.png,ץ̾¸(R):m54:R,SP,ץ(E):m55:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,ץȽλ(C):m56:C:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","h4:WSSTR  Option(O)"," ץ(O)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","i4:WSSTR Environment(E)    :m61:E,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L","Ķ(E)      :m61:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,(C):m62:C,ե(F):m63:F,åɥե(L):m64:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","j4:WSSTR  Help(H)"," إ(H)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","k4:WSSTR Index(I):m81:I,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L","ܼ(I):m81:I:0:$(WSDIR)/sys/pixmaps/help.png,ե(R)     :m82:R,Ȥ(U):m83:U,С(V):m84:V,饤󥹾(L):m85:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","l4:WSSTR Please specify a window to save.","¸ɥ򤷤Ʋ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","m4:WSSTR Continue saving?","¸³ޤ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","n4:WSSTR Please specify some instances to copy.","ԡ󥹥󥹤򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","o4:WSSTR Please specify a instance to paste.","Žդ򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","p4:WSSTR Some instances are selected to paste.\nPlease specify a instance.","Žդ褬ʣ򤵤Ƥޤ.\nĤ򤷤Ʋ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","q4:WSSTR Please select the instance to delete.","󥹥󥹤򤷤Ƥ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","r4:WSSTR Delete instance: ","󥹥: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","s4:WSSTR  ?"," ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","t4:WSSTR Please specify a instance to display.","ɽ󥹥󥹤򤷤Ƥ. ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","u4:WSSTR There is no instance for search.","оݤȤʤ륪֥ȡ󥹥󥹤ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","v4:WSSTR Please specify a application window to compile.","ѥ뤷ɥ򤷤Ʋ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","w4:WSSTR Please check the debugger settings or confirm whether the project is built.","ǥХåλ꤬ᥤƤ뤫ǧƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","x4:WSSTR Can not execute the class library...","饤֥μ¹ԤϽޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","y4:WSSTR Can not execute the load module.\nPlease confirm whether the project is collect or built.","ɥ⥸塼뤬¹ԤǤޤ\nץȤᥤƤ뤫ǧƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","z4:WSSTR Please specify a application window to generate source code.","ɥ򤷤Ʋ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","A4:WSSTR Please wait for a while to start web browser..","إץ֥饦Ω夬ޤФ餯Ԥ...");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","B4:WSSTR NoName","̵");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","C4:WSSTR Unexpected error occurred in reading the project files...","ץȤɤ߹ߤǥ顼ȯޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","D4:WSSTR Can not open File: ","Ͽե: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","E4:WSSTR  .","\nɤ߹ߤǥ顼ȯޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","F4:WSSTR Can not save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","G4:WSSTR  .","νϤ˼Ԥޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","H4:WSSTR The project was modified.\nSave it?","ץȤѹƤޤ\n¸ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","I4:WSSTR Abort saving the application window.","ɥ¸Ǥޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","J4:WSSTR Some application windows were modified \nSave them?","ɥѹƤޤ\n¸ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","K4:WSSTR The project has no name.\nName the project and save it?","ץȤ̵̾Ǥ\n̾Τդ¸򤷤ޤ?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","L4:WSSTR Exit the application builder?","ӥλޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","M4:WSSTR Sorry, under construction...","ߤޤ󤬡Ǥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","N4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","O4:WSSTR Do you continue?","νϤ˼ԤޤϤ³ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","P4:WSSTR \",\n","ޤ\",\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Q4:WSSTR No project is specified.\nGenerate a new project?","ץȤꤵƤޤ\nץȤ򳫤ץȤƤ.\nץȤޤ?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","R4:WSSTR Please specify a keyword to search files.","ե˴ޤޤʸꤷƤ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","S4:WSSTR No editor is specified.\nPlease confirm the project settings and specify the editor.","ǥꤵƤޤ\nץǥǥꤷƤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","S4:WSSTR No editor option is specified.\nPlease confirm the project settings and specify the editor.","ǥץ󤬻ꤵƤޤ\nץǥǥץꤷƤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","T4:WSSTR New project","ץȤκ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","U4:WSSTR < Back,Next >,Finish","< , >,");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","V4:WSSTR Project name","ץ̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","W4:WSSTR Working dir","ȥǥ쥯ȥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","X4:WSSTR Project type","ץȼ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR  Normal application"," ̾Υץꥱ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Z4:WSSTR  Class library component"," 饹饤֥ꥳݡͥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","W4:WSSTR New application window","ɥκ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","X4:WSSTR < Back,Next >,Finish","< , >,");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR Type","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Z4:WSSTR  Normal window"," ̾Υɥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","a4:WSSTR  Class"," 饹");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","b4:WSSTR Project","Ͽ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","c4:WSSTR  Add to project"," ץȤϿ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","d4:WSSTR Name","̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","e4:WSSTR Please specify a instance name to search.","(󥹥̾)ꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","f4:WSSTR Please specify a value of the property to search instance.","(ץѥƥ)ꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","f4:WSSTR Please specify a property name likes [WSN...] to search instance.","WSN... ǻϤޤץѥƥ̾ꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","g4:WSSTR Please specify search condition.","ꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","h4:WSSTR No instance.","ꤵ줿󥹥󥹤ϸդޤǤ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","i4:WSSTR Find instances","󥹥󥹤θ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","j4:WSSTR Find","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","k4:WSSTR Instance name,Properties,Procedures","󥹥̾,ץѥƥ,ץ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","l4:WSSTR InstanceName","󥹥̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","m4:WSSTR Comparison","ˡ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","n4:WSSTR  Complete equal","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","o4:WSSTR PropertyName","ץѥƥ̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","p4:WSSTR Value","ץѥƥ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","q4:WSSTR ProcedureName","ץ̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","r4:WSSTR FunctionName","ؿ̾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","s4:WSSTR Direction","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","t4:WSSTR  Downward"," ظ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","u4:WSSTR  Upward"," ظ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","v4:WSSTR Find files","եθ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","w4:WSSTR < Back,Find, Find","< ,, ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","x4:WSSTR Dir:","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","y4:WSSTR File type:","ե륿");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","z4:WSSTR Keyword:","ޤʸ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","A4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","B4:WSSTR .","\nνϤ˼Ԥޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","C4:WSSTR Delete instance:","󥹥:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","D4:WSSTR ?","\nƤǤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","E4:WSSTR Add application window: ","ɥ: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","F4:WSSTR  to the project?"," ץȤϿޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","G4:WSSTR Remove application window: ","ɥ: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","H4:WSSTR  from the project?"," ץȤؤϿޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","I4:WSSTR Failed to read file:","ե: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","J4:WSSTR .\nDo you stop reading?","\nɤ߹˥顼ȯޤ\nɤ߹ߤߤޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","K4:WSSTR Failed to open File: ","ե: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","L4:WSSTR .","\nץǤޤǤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","M4:WSSTR Failed to write File: ","ե: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","N4:WSSTR .","\nǽ񤭹ߥ顼ȯޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","O4:WSSTR Invalid name: ","̵̾: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","P4:WSSTR .\nPlease specify a usable name in C/C++ variables.","\n C/C++ǻѤǤѿ̾ΤꤷƤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","P4:WSSTR .\nAlready used by project name.",".\nץ̾Ȱۤʤ̾ΤꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","P4:WSSTR .\nCan not use array name.",".\n̾ϻǤޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Q4:WSSTR Can not generate the specified class: ","ꤵ줿饹: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","R4:WSSTR ."," ޤ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","S4:WSSTR Can not change the specified class: ","ꤵ줿饹: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","T4:WSSTR  to window type.\nPlease specify a class of window/dialog base."," ϥɥ˽ޤ\n ɥ١Ȥ饹ꤷƲ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","U4:WSSTR Can not paste the instance on the specified instance: ","󥹥: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","V4:WSSTR ."," Ф\n¾Υ󥹥󥹤Žդ뤳ȤϤǤޤ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","W4:WSSTR Can not paste the specified instance: ","󥹥: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","X4:WSSTR ,\nbecause it overlap the source and the destination...","ԡȥԡŤʤäƤޤ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR Locale type","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Y4:WSSTR Templates","ƥץ졼");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","Z4:WSSTR Can not read file:","ե:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","a4:WSSTR .","\n ɤ߹ޤǤ$(WSDIR) ǧƲ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.eucjp","a4:WSSTR Look and Feel","åɥե");
